@@ -35,8 +35,7 @@ Usage::
 """
 from typing import Generic, Iterator, TypeVar
 
-from botocore.paginate import PageIterator
-from botocore.paginate import Paginator as Boto3Paginator
+from botocore.paginate import PageIterator, Paginator
 
 from .type_defs import (
     ListDatasetsResponseTypeDef,
@@ -72,7 +71,7 @@ class _PageIterator(Generic[_ItemTypeDef], PageIterator):
         """
 
 
-class ListDatasetsPaginator(Boto3Paginator):
+class ListDatasetsPaginator(Paginator):
     """
     [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/databrew.html#GlueDataBrew.Paginator.ListDatasets)
     [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_databrew/paginators/#listdatasetspaginator)
@@ -87,7 +86,7 @@ class ListDatasetsPaginator(Boto3Paginator):
         """
 
 
-class ListJobRunsPaginator(Boto3Paginator):
+class ListJobRunsPaginator(Paginator):
     """
     [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/databrew.html#GlueDataBrew.Paginator.ListJobRuns)
     [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_databrew/paginators/#listjobrunspaginator)
@@ -102,7 +101,7 @@ class ListJobRunsPaginator(Boto3Paginator):
         """
 
 
-class ListJobsPaginator(Boto3Paginator):
+class ListJobsPaginator(Paginator):
     """
     [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/databrew.html#GlueDataBrew.Paginator.ListJobs)
     [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_databrew/paginators/#listjobspaginator)
@@ -121,7 +120,7 @@ class ListJobsPaginator(Boto3Paginator):
         """
 
 
-class ListProjectsPaginator(Boto3Paginator):
+class ListProjectsPaginator(Paginator):
     """
     [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/databrew.html#GlueDataBrew.Paginator.ListProjects)
     [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_databrew/paginators/#listprojectspaginator)
@@ -136,7 +135,7 @@ class ListProjectsPaginator(Boto3Paginator):
         """
 
 
-class ListRecipeVersionsPaginator(Boto3Paginator):
+class ListRecipeVersionsPaginator(Paginator):
     """
     [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/databrew.html#GlueDataBrew.Paginator.ListRecipeVersions)
     [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_databrew/paginators/#listrecipeversionspaginator)
@@ -151,7 +150,7 @@ class ListRecipeVersionsPaginator(Boto3Paginator):
         """
 
 
-class ListRecipesPaginator(Boto3Paginator):
+class ListRecipesPaginator(Paginator):
     """
     [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/databrew.html#GlueDataBrew.Paginator.ListRecipes)
     [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_databrew/paginators/#listrecipespaginator)
@@ -166,7 +165,7 @@ class ListRecipesPaginator(Boto3Paginator):
         """
 
 
-class ListRulesetsPaginator(Boto3Paginator):
+class ListRulesetsPaginator(Paginator):
     """
     [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/databrew.html#GlueDataBrew.Paginator.ListRulesets)
     [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_databrew/paginators/#listrulesetspaginator)
@@ -181,7 +180,7 @@ class ListRulesetsPaginator(Boto3Paginator):
         """
 
 
-class ListSchedulesPaginator(Boto3Paginator):
+class ListSchedulesPaginator(Paginator):
     """
     [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/databrew.html#GlueDataBrew.Paginator.ListSchedules)
     [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_databrew/paginators/#listschedulespaginator)
